[![Build Status](https://travis-ci.org/jcanton/pymech.svg?branch=master)](https://travis-ci.org/jcanton/pymech/builds)
[![Coverage Status](https://coveralls.io/repos/github/jcanton/pymech/badge.png?branch=master)](https://coveralls.io/github/jcanton/pymech?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pymech/badge/?version=latest)](http://pymech.readthedocs.org/en/latest/?badge=latest)

# pymech

A Python suite of routines for *Nek5000* and *Simson*.

by Jacopo Canton, Guillaume Chauvat, Nicolò Fabbiane and Ashwin Vishnu Mohanan<br>
[@jcanton](https://github.com/jcanton)
[@guillaumechauvat](https://github.com/guillaumechauvat)
[@nfabbiane](https://github.com/nfabbiane)
[@ashwinvis](https://github.com/ashwinvis)

Install with `pip install pymech`

Read the full documentation at [Pymech doc](http://pymech.readthedocs.io).
